@@ -193,7 +193,7 @@ get_bno_rec(
 	struct xfs_btree_cur	*cur,
 	struct extent_tree_node	*prev_value)
 {
-	xfs_agnumber_t		agno = cur->bc_ag.agno;
+	xfs_agnumber_t		agno = cur->bc_ag.pag->pag_agno;
 
 	if (cur->bc_btnum == XFS_BTNUM_BNO) {
 		if (!prev_value)
@@ -226,13 +226,14 @@ get_bnobt_record(
 void
 init_freespace_cursors(
 	struct repair_ctx	*sc,
-	xfs_agnumber_t		agno,
+	struct xfs_perag	*pag,
 	unsigned int		free_space,
 	unsigned int		*nr_extents,
 	int			*extra_blocks,
 	struct bt_rebuild	*btr_bno,
 	struct bt_rebuild	*btr_cnt)
 {
+	xfs_agnumber_t		agno = pag->pag_agno;
 	unsigned int		agfl_goal;
 	int			error;
 
@@ -242,9 +243,9 @@ init_freespace_cursors(
 	init_rebuild(sc, &XFS_RMAP_OINFO_AG, free_space, btr_cnt);
 
 	btr_bno->cur = libxfs_allocbt_stage_cursor(sc->mp,
-			&btr_bno->newbt.afake, agno, XFS_BTNUM_BNO);
+			&btr_bno->newbt.afake, pag, XFS_BTNUM_BNO);
 	btr_cnt->cur = libxfs_allocbt_stage_cursor(sc->mp,
-			&btr_cnt->newbt.afake, agno, XFS_BTNUM_CNT);
+			&btr_cnt->newbt.afake, pag, XFS_BTNUM_CNT);
 
 	btr_bno->bload.get_record = get_bnobt_record;
 	btr_bno->bload.claim_block = rebuild_claim_block;
@@ -354,7 +355,7 @@ get_ino_rec(
 	struct xfs_btree_cur	*cur,
 	struct ino_tree_node	*prev_value)
 {
-	xfs_agnumber_t		agno = cur->bc_ag.agno;
+	xfs_agnumber_t		agno = cur->bc_ag.pag->pag_agno;
 
 	if (cur->bc_btnum == XFS_BTNUM_INO) {
 		if (!prev_value)
@@ -437,7 +438,7 @@ get_inobt_record(
 void
 init_ino_cursors(
 	struct repair_ctx	*sc,
-	xfs_agnumber_t		agno,
+	struct xfs_perag	*pag,
 	unsigned int		free_space,
 	uint64_t		*num_inos,
 	uint64_t		*num_free_inos,
@@ -445,6 +446,7 @@ init_ino_cursors(
 	struct bt_rebuild	*btr_fino)
 {
 	struct ino_tree_node	*ino_rec;
+	xfs_agnumber_t		agno = pag->pag_agno;
 	unsigned int		ino_recs = 0;
 	unsigned int		fino_recs = 0;
 	bool			finobt;
@@ -486,7 +488,7 @@ init_ino_cursors(
 	}
 
 	btr_ino->cur = libxfs_inobt_stage_cursor(sc->mp, &btr_ino->newbt.afake,
-			agno, XFS_BTNUM_INO);
+			pag, XFS_BTNUM_INO);
 
 	btr_ino->bload.get_record = get_inobt_record;
 	btr_ino->bload.claim_block = rebuild_claim_block;
@@ -506,7 +508,7 @@ _("Unable to compute inode btree geometry, error %d.\n"), error);
 
 	init_rebuild(sc, &XFS_RMAP_OINFO_INOBT, free_space, btr_fino);
 	btr_fino->cur = libxfs_inobt_stage_cursor(sc->mp,
-			&btr_fino->newbt.afake, agno, XFS_BTNUM_FINO);
+			&btr_fino->newbt.afake, pag, XFS_BTNUM_FINO);
 
 	btr_fino->bload.get_record = get_inobt_record;
 	btr_fino->bload.claim_block = rebuild_claim_block;
@@ -574,17 +576,18 @@ get_rmapbt_record(
 void
 init_rmapbt_cursor(
 	struct repair_ctx	*sc,
-	xfs_agnumber_t		agno,
+	struct xfs_perag	*pag,
 	unsigned int		free_space,
 	struct bt_rebuild	*btr)
 {
+	xfs_agnumber_t		agno = pag->pag_agno;
 	int			error;
 
 	if (!xfs_sb_version_hasrmapbt(&sc->mp->m_sb))
 		return;
 
 	init_rebuild(sc, &XFS_RMAP_OINFO_AG, free_space, btr);
-	btr->cur = libxfs_rmapbt_stage_cursor(sc->mp, &btr->newbt.afake, agno);
+	btr->cur = libxfs_rmapbt_stage_cursor(sc->mp, &btr->newbt.afake, pag);
 
 	btr->bload.get_record = get_rmapbt_record;
 	btr->bload.claim_block = rebuild_claim_block;
@@ -644,10 +647,11 @@ get_refcountbt_record(
 void
 init_refc_cursor(
 	struct repair_ctx	*sc,
-	xfs_agnumber_t		agno,
+	struct xfs_perag	*pag,
 	unsigned int		free_space,
 	struct bt_rebuild	*btr)
 {
+	xfs_agnumber_t		agno = pag->pag_agno;
 	int			error;
 
 	if (!xfs_sb_version_hasreflink(&sc->mp->m_sb))
@@ -655,7 +659,7 @@ init_refc_cursor(
 
 	init_rebuild(sc, &XFS_RMAP_OINFO_REFC, free_space, btr);
 	btr->cur = libxfs_refcountbt_stage_cursor(sc->mp, &btr->newbt.afake,
-			agno);
+			pag);
 
 	btr->bload.get_record = get_refcountbt_record;
 	btr->bload.claim_block = rebuild_claim_block;
